package hirondelle.web4j.config;

import javax.servlet.ServletConfig;
import hirondelle.web4j.StartupTasks;
import hirondelle.web4j.database.DAOException;
import hirondelle.web4jtools.codegenerator.action.ActionAction;
import hirondelle.web4jtools.codegenerator.codes.Enumerations;
import hirondelle.web4jtools.util.SaveToFile;
import hirondelle.web4jtools.metrics.base.FileInfo;
import hirondelle.web4jtools.metrics.comments.CommentsAction;
import hirondelle.web4jtools.logview.directories.LogInfoDAO;
import hirondelle.web4jtools.logview.simpleview.LogFileDAO;
import hirondelle.web4jtools.metrics.tabs.TabsRemoveAction;
import hirondelle.web4jtools.metrics.base.BaseInfoDAO;

/** Implementation of {@link StartupTasks}, required by WEB4J.  */
public final class Startup implements StartupTasks {

  /** 
  * Perform startup tasks.
  *
  * Calls {@link #lookUpCodeTablesAndPlaceIntoAppScope()}, and calls various static initialization methods.
  * This method passes around access to the config settings in <tt>web.xml</tt>.
  */
  public void startApplication(ServletConfig aConfig, String aDbName) throws DAOException {
    //has no databases, so no need to branch here
    fConfig = aConfig;
    lookUpCodeTablesAndPlaceIntoAppScope();
    SaveToFile.readConfig(fConfig);
    ActionAction.readConfig(fConfig);
    FileInfo.readConfig(fConfig);
    CommentsAction.readConfig(fConfig);
    BaseInfoDAO.readConfig(fConfig);
    LogInfoDAO.readConfig(fConfig);
    LogFileDAO.readConfig(fConfig);
    TabsRemoveAction.readConfig(fConfig);
  }
  
  /**
  * Called upon startup, and when the content of a code table changes.
  *
  * <P>Refreshes the copies of code tables placed in application scope.
  * <em>(In this case, the code tables are enums, and are never changed after application
  * startup. However, this style is retained, since it is both simple, and possibly useful 
  * for future use.)</em>
  */
  public static void lookUpCodeTablesAndPlaceIntoAppScope() throws DAOException {
    Enumerations.init(fConfig.getServletContext());
  }
  
  // PRIVATE //
  private static ServletConfig fConfig;
}
