package hirondelle.web4jtools.codegenerator.codes;

import javax.servlet.ServletContext;

/** Place enumerations in application scope upon startup.  */
public final class Enumerations {

  /**
  * Place all needed enumerations into application scope.
  * 
  * <P>Enums are placed in app scope as an array, using the enum's simple class name as key, and
  * the enum <tt>values()</tt> as the value (which returns an array). 
  * 
  * <P>When such values are posted, it is recommended that they be immediately translated into 
  * a member of the enum, using, <tt>valueOf(String)</tt>.
  */
  public static void init(ServletContext aContext){
    initEnum(FieldType.class, FieldType.values(), aContext);
    initEnum(UiStyle.class,  UiStyle.values(), aContext);
    initEnum(ControlStyle.class, ControlStyle.values(), aContext);
    initEnum(ShowOperation.class, ShowOperation.values(), aContext);
    initEnum(ApplyOperation.class, ApplyOperation.values(), aContext);
  }

  // PRIVATE //
  private static <T> void  initEnum(Class<T> aEnumClass, T[] aValues, ServletContext aContext){
    aContext.setAttribute(aEnumClass.getSimpleName(), aValues);
  }
}
