<%-- Fields : the data attached to a Feature. --%>
<%@ include file="/JspHeader.jsp" %>

<w:help>
<div class="help">
<w:txt wikiMarkup="true" translate="false">
  Input the various fields associated with a feature. 
  These items correspond to database columns.
  
  Tooltips are provided for each field, as reminders.
  
  The _Required_ checkbox refers specifically to how the field is treated in Java, in a Model Object, and 
  not how it is treated as a database column.
  It is often the case that fields for database primary keys are *not* required, because of the 
  following issue : when creating a new record using an INSERT operation, the data needs to be 
  first represented in a Model Object. At this stage, however, the primary key has not yet been assigned. 
  Thus, for such Model Objects, a primary key cannot be a required item.
  
  The _Min_ and _Max_ fields refer either to the actual numeric value of a field, or, if it is a text field, to the number of characters.
  See the [link:http://www.web4j.com/web4j/javadoc/hirondelle/web4j/model/Check.html Check] class for more information.
  
  To understand the difference between hard and soft validation, please see
  [link:http://www.web4j.com/web4j/javadoc/hirondelle/web4j/security/ApplicationFirewall.html ApplicationFirewall]. 
</w:txt>
</div>
</w:help>


<c:url value="FieldAction.do" var="baseURL"/> 
<w:populate using="itemForEdit">
 <form action='${baseURL}' method="post" class="user-input-simple" name='giveMeFocus'>
   <fieldset>
   <legend>Basic Field Info</legend>

   <label title='Field Name. Example: "Jet Engine"'>Name</label> * <input name="Name" type="text" title='Field Name. Example "Jet Engine"'.>
   
   <label title='Java data type'>Type</label> *
   <select name="Type" title='Java data type'>
    <option> </option>
    <c:forEach var="item" items="${FieldType}">
      <option value="${item}">${item}</option>
    </c:forEach>
   </select>
   
   <label title='User interface widget'>Control Style</label> *
   <select name="ControlStyle" title='User interface widget'>
    <option> </option>
    <c:forEach var="item" items="${ControlStyle}">
      <option value="${item}">${item}</option>
    </c:forEach>
   </select>

   <label title='Code Table. Only for SELECT and RADIO. Name of app scope list of codes.'>Code Table</label> <input name="CodeTable" type="text" title='Code Table. Only for SELECT and RADIO. Name of app scope list of codes.'>
   
   <P><label title='Is the field required or optional?'>Is Required?</label> 
   <input name="IsRequired" type="checkbox" value="true"  title='Is the field required or optional?'>
   
   <label title='Is the field a primary key?'>Is Primary Key?</label> <input name="IsPrimaryKey" type="checkbox" value="true"  title='Is the field a primary key?'>

   <label title='Javadoc description'>Description</label> <input name="Description" type="text" size='50'  title='Javadoc description'>
   
   <P><label title='Error message when user inputs invalid value.'>Message for Invalid Input</label> <input name="ErrorMessage" type="text" size='50'  title='Error message when user inputs invalid value.'>
   <label title='Should lists sort on this field?'>Sort On This Field?</label> <input name='IsOrderByField' type='checkbox' value='true'  title='Should lists sort on this field?'>
   <label title='Defaults to ASC'>DESC</label> <input name='IsDescendingOrder' type='checkbox' value='true'  title='Defaults to ASC'>
   
   </fieldset>
   
   <fieldset>
    <legend>Soft Validation</legend>
    <label title='Minimum value.'>Min</label> <input name="Minimum" type="text"  title='Minimum value.'>
    <label title='Maximum value.'>Max</label> <input name="Maximum" type="text" title='Maximum value.'>
    <label title='Maximum number of decimal places, if any'>Max Num Decimals</label> <input name="NumDecimals" type="text" title='Maximum number of decimal places, if any'>
    <P><label title='Does the field hold an email address?'>Is Email Address?</label>    <input name="CheckEmail" type='checkbox' value='true' title='Does the field hold an email address?'>
    <label title='Should this text field be checked for spam?'>Check for Spam?</label> <input name='CheckSpam' type='checkbox' value='true' title='Should this be filtered for spam?'>
    <label title='Regular expression'>Pattern</label> <input name="CheckPattern" type='text' title='Regular expression'>
   </fieldset>

   <fieldset>
    <legend>Hard Validation</legend>
    <label title='Should the field have a sanity check for large size?'>Length?</label> <input checked name="IsHardValidatedForLength" type="checkbox" value="true"  title='Should the field have a sanity check for large size?'>
    <label title='Regular Expression'>Pattern</label> <input name="HardValidationPattern" type='text' title='Regular Expression'>
   </fieldset>
   
</w:populate>

   UPDATE : <input type="submit" value='Add/Edit'> 
   <input name="Id" type="hidden" value='${param.Id}'>
  
  <tags:hiddenOperationParam/>
</form>

<P>Fields for <b>${w:safe(feature.name)}</b> feature :
 <table class="report" align="center" rules='groups'> 
  <colgroup span='7'>
  <colgroup span='6'>
  <colgroup span='2'>
  <tr>
   <td colspan='7'>Basic Field Info</td>
   <td colspan='7'>Soft Validation</td>
   <td colspan='2'>Hard Validation</td>
  </tr>
  <tr>
   <th title="Id">#</th>
   <th title='Field Name'>Name</th>
   <th title='Java data type'>Type</th>
   <th title='User interface widget'>Control</th>
   <th title='Name of code table in app scope'>Code</th>
   <th title='Is Required Field?'>Req</th>
   <th title='Is Primary Key?'>PK</th>
   <th title='Sort By This Field?'>Sort</th>
   <th title='Minimum value or length'>Min</th>
   <th title='Maximum value or length'>Max</th>
   <th title='Maximum number of decimal places, if any'>Dec</th>
   <th title='Is email address?'>Email</th>
   <th title='Should be checked for spam?'>Spam</th>
   <th title='Regular Expression'>Pattern</th>
   <th title='Hard Validation: length only?'>Length</th>
   <th title='Hard Validation: regular expression.'>Pattern</th>
  </tr>

<w:alternatingRow> 
<c:forEach var="item" items="${itemsForListing}" varStatus="index">
  <tr class="row_highlight">
   <td title="Id">${index.count}</td>
   <td title='Field Name'>${w:safe(item.name)}</td>
   <td title='Java data type'>${item.type}</td>
   <td title='User interface widget'>${item.controlStyle}</td>
   <td title='Name of code table in app scope'>${item.codeTable}</td>
   <td title='Is required field?' align="center"><tags:showBoolean value='${item.isRequired}'/></td>
   <td title='Is primary key?' align="center"><tags:showBoolean value='${item.isPrimaryKey}'/> </td>
   <td title='Sort By This Field?'>${item.sortOrder}</td>
   <td title='Minimum value or length'>${item.minimum}</td>
   <td title='Maximum value or length'>${item.maximum}</td>
   <td title='Maximum number of decimals, if any'>${item.numDecimals}</td>
   <td title='Is email address?' align='center'><tags:showBoolean value='${item.checkEmail}'/></td>
   <td title='Should be checked for spam' align='center'><tags:showBoolean value='${item.checkSpam}'/></td>
   <td title='Regular expression'>${w:safe(item.checkPattern)}</td>
   <td title='Hard Validation: length only?' align='center'><tags:showBoolean value='${item.isHardValidatedForLength}'/></td>
   <td title='Hard Validation: regular expression.'>${w:safe(item.hardValidationPattern)}</td>
   <tags:editLinks baseURI="${baseURL}" id="${index.count - 1}"/>
  </tr>
</c:forEach>
</w:alternatingRow>
</table>
