package hirondelle.web4jtools.codegenerator.model;

import java.util.*;
import hirondelle.web4j.model.AppException;
import hirondelle.web4j.action.ActionImpl;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4j.action.ResponsePage;
import hirondelle.web4j.util.Util;
import hirondelle.web4jtools.util.TemplatedPage;
import hirondelle.web4jtools.codegenerator.codes.FieldType;
import hirondelle.web4jtools.codegenerator.field.Field;
import hirondelle.web4jtools.codegenerator.field.FieldAction;

/**
* Generate a Model Object for the feature, and serve as plain text.
* 
* <P>Uses the {@link hirondelle.web4jtools.codegenerator.feature.Feature} and 
* List of {@link hirondelle.web4jtools.codegenerator.field.Field} objects placed in session scope.
*/
public final class ModelAction extends ActionImpl{ 

  public ModelAction(RequestParser aRequestParser){
    super(FORWARD, aRequestParser);
  }
  
  @Override public ResponsePage execute() throws AppException {
    addToRequest("imports", getImports());
    return getResponsePage();
  }
  
  // PRIVATE //
  private static final ResponsePage FORWARD = TemplatedPage.getPlain("Generated Model", "view.jsp", ModelAction.class);
  
  private List<String> getImports(){
    List<String> result = new ArrayList<String>();

    Set<FieldType> types = getFieldTypes();

    for(FieldType type : types){
      //qualified name is null if in java.lang - no import required
      if (Util.textHasContent(type.getQualifiedName())){
        result.add(type.getQualifiedName());
      }
    }
    
    return result;
  }

  private Set<FieldType> getFieldTypes() {
    Set<FieldType> types = new LinkedHashSet<FieldType>();
    List<Field> fields = (List<Field>)getFromSession(FieldAction.FIELDS_KEY);
    if ( fields != null ){
      for(Field field : fields) {
        types.add(field.getType());
      }
    }
    return types;
  }
}
