package hirondelle.web4jtools.codegenerator.sql;

import hirondelle.web4j.model.AppException;
import hirondelle.web4j.action.ActionImpl;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4j.action.ResponsePage;
import hirondelle.web4jtools.util.TemplatedPage;
import java.util.*;

import hirondelle.web4jtools.codegenerator.codes.UiStyle;
import hirondelle.web4jtools.codegenerator.feature.Feature;
import hirondelle.web4jtools.codegenerator.feature.FeatureAction;
import hirondelle.web4jtools.codegenerator.field.Field;
import hirondelle.web4jtools.codegenerator.field.FieldAction;

/**
* Generate the .sql file needed for the feature, and serve it in plain text.
* 
* <P>The .sql file is used by the DAO class.
*/
public final class SqlAction extends ActionImpl {
  
  public SqlAction(RequestParser aRequestParser){
    super(LIST_AND_EDIT, aRequestParser);
  }

  @Override public ResponsePage execute() throws AppException {
    addToRequest("primaryKey", getPrimaryKeyName());
    addToRequest("orderBy", getOrderBy());
    addToRequest("sortOrder", getSortOrder());
    
    UiStyle uiStyle = getUiStyle();
    if ( UiStyle.ListAndEdit == uiStyle ) {
      //use default forward
    }
    else if ( UiStyle.ShowAndApply == uiStyle ) {
      setResponsePage(SHOW_AND_APPLY);
    }
    else {
      throw new AssertionError("Unexpected value for UiStyle : " + uiStyle);
    }
    
    return getResponsePage();
  }
  
  // PRIVATE //
  private static final ResponsePage LIST_AND_EDIT = TemplatedPage.getPlain("Sql File","listAndEdit.jsp", SqlAction.class);
  private static final ResponsePage SHOW_AND_APPLY = TemplatedPage.getPlain("Sql File", "showAndApply.jsp", SqlAction.class);
  
  private UiStyle getUiStyle() {
    Feature feature = (Feature)getFromSession(FeatureAction.FEATURE_KEY);
    return feature.getUiStyle();
  }
  
  private String getPrimaryKeyName(){
    String result = null;
    List<Field> fields = (List<Field>)getFromSession(FieldAction.FIELDS_KEY);
    for(Field field: fields){
      if ( field.getIsPrimaryKey() ) {
        result = field.getName();
        break;
      }
    }
    return result;
  }
  
  private String getOrderBy() {
    String result = "?";
    List<Field> fields = (List<Field>)getFromSession(FieldAction.FIELDS_KEY);
    for (Field field : fields){
      if ( field.getIsOrderByField() ) {
        result = field.getName().toString();
        break;
      }
    }
    return result;
  }
  
  private String getSortOrder(){
    String result = "";
    List<Field> fields = (List<Field>)getFromSession(FieldAction.FIELDS_KEY);
    for (Field field : fields){
      if ( field.getIsOrderByField() ) {
        result = field.getSortOrder().toString();
      }
    }
    return result;
  }
}
