package hirondelle.web4jtools.logview.downtime;

import hirondelle.web4j.action.ActionImpl;
import hirondelle.web4j.action.ResponsePage;
import hirondelle.web4j.model.AppException;
import hirondelle.web4j.model.ModelCtorException;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4j.util.Util;
import hirondelle.web4jtools.logview.parsedview.LoggerRecord;
import hirondelle.web4jtools.logview.simpleview.LogFileDAO;

import java.io.File;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.logging.Logger;

/**
* Display list of application down times, and their durations.
* 
* <P>It is recommended that the view suppress display of items 
* having small down times (say, under 2-3 minutes).
*/
public final class DownTimeAction extends ActionImpl {

  public DownTimeAction(RequestParser aRequestParser) {
    super(FORWARD, aRequestParser);
  }
  
  @Override public ResponsePage execute() throws AppException {
    
    LogFileDAO dao = new LogFileDAO(getRequestParser().getRequest());
    
    List<File> allAppLogFiles = dao.listAllAppLogFiles();
    List<LoggerRecord> firstRecords = dao.listFirstRecordsFor(allAppLogFiles);
    List<DownTime> downtimes = calculateDownTimes(allAppLogFiles, firstRecords);
    
    addToRequest("downTimes" , downtimes);
    return getResponsePage();
  }
  
  // PRIVATE //
  private static final ResponsePage FORWARD = new ResponsePage("Down Time From Logs", "view.jsp", DownTimeAction.class);
  private static final Logger fLogger = Util.getLogger(DownTimeAction.class);
  
  private List<DownTime> calculateDownTimes(List<File> aAllAppLogFiles, List<LoggerRecord> aFirstRecords) {
    fLogger.fine("Num files : " + aAllAppLogFiles.size());
    fLogger.fine("Num First Records: " + aFirstRecords.size());
    List<DownTime> result = new ArrayList<DownTime>();
    for (int idx = 1; idx <= aFirstRecords.size() - 1 ; ++idx) {
      Date from = new Date(aAllAppLogFiles.get(idx-1).lastModified());
      Date to = aFirstRecords.get(idx).getDate();
      DownTime downTime = null;
      try {
        downTime = new DownTime(from, to);
      }
      catch(ModelCtorException ex){
        throw new RuntimeException(ex);
      }
      result.add(downTime);
    }
    return result;
  }
}
