package hirondelle.web4jtools.logview.parsedview;

import hirondelle.web4j.action.ActionTemplateSearch;
import hirondelle.web4j.action.ResponsePage;
import hirondelle.web4j.model.AppException;
import hirondelle.web4j.model.ModelCtorException;
import hirondelle.web4j.model.ModelFromRequest;
import hirondelle.web4j.request.RequestParameter;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4jtools.logview.simpleview.LogFileDAO;

import java.io.File;
import java.util.Date;

/**
* List parsed logger records, according to given criteria. 
*/
public final class ParsedViewAction extends ActionTemplateSearch {
  
  public ParsedViewAction(RequestParser aRequestParser) {
    super(FORWARD, aRequestParser);
  }
  
  public static final RequestParameter LOG_FOR = RequestParameter.withRegexCheck("Log For", "(Application|Server)");
  public static final RequestParameter LEVEL = RequestParameter.withRegexCheck("Level", "(SEVERE|WARNING|INFO|CONFIG|FINE|FINER|FINEST)");
  public static final RequestParameter MIN_DATE = RequestParameter.withLengthCheck("Min Date");
  public static final RequestParameter MAX_DATE = RequestParameter.withLengthCheck("Max Date");
  public static final RequestParameter LOGGER_STARTS_WITH = RequestParameter.withLengthCheck("Logger Starts With");
  public static final RequestParameter METHOD_NAME = RequestParameter.withLengthCheck("Method Name");
  public static final RequestParameter MESSAGE_CONTAINS = RequestParameter.withLengthCheck("Message Contains");
  public static final RequestParameter REVERSE_ORDER = RequestParameter.withRegexCheck("Reverse Order", "(true)");
  
  /** Check that user input can create a {@link ParsedCriteria} object.  */
  @Override  protected void validateUserInput() throws AppException {
    ModelFromRequest builder = new ModelFromRequest(getRequestParser());
    try {
      fCriteria = builder.build(
        ParsedCriteria.class, LOG_FOR,  LEVEL, MIN_DATE, MAX_DATE, 
        LOGGER_STARTS_WITH, METHOD_NAME, MESSAGE_CONTAINS, REVERSE_ORDER
      );
    }
    catch (ModelCtorException ex){
      addError(ex);
    }
  }
  
  /** List the log records matching the given criteria.  */
  @Override protected void listSearchResults() throws AppException {
    LogFileDAO dao = new LogFileDAO(getRequestParser().getRequest());
    File mostRecentLog = dao.getMostRecentLogFile(fCriteria.getLogFor());
    if ( mostRecentLog != null ) {
      addToRequest("mostRecentLog", mostRecentLog);
      addToRequest("mostRecentLogDate", new Date(mostRecentLog.lastModified()));
      addToRequest("mostRecentLogSize", mostRecentLog.length());
      addToRequest(ITEMS_FOR_LISTING, dao.getParsedLogFile(mostRecentLog, fCriteria));
    }
    else {
      addError("No files detected in logging directory");
    }
  }

  // PRIVATE //
  private ParsedCriteria fCriteria;
  private static final ResponsePage FORWARD = new ResponsePage("Parsed Logs", "view.jsp", ParsedViewAction.class);
}
