package hirondelle.web4jtools.logview.simpleview;

import hirondelle.web4j.action.ActionTemplateSearch;
import hirondelle.web4j.action.ResponsePage;
import hirondelle.web4j.model.AppException;
import hirondelle.web4j.model.ModelCtorException;
import hirondelle.web4j.model.ModelFromRequest;
import hirondelle.web4j.request.RequestParameter;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4j.util.Util;

import java.io.File;
import java.util.Date;
import java.util.logging.Logger;

/**
* View application or server logs as plain text, without parsing. 
*/
public final class SimpleViewAction extends ActionTemplateSearch {

  public SimpleViewAction(RequestParser aRequestParser){
    super(FORWARD, aRequestParser);
  }

  public static final RequestParameter LOG_FOR = RequestParameter.withLengthCheck("LogFor");
  public static final RequestParameter NUM_LINES = RequestParameter.withLengthCheck("NumLines");
  public static final RequestParameter SECTION = RequestParameter.withRegexCheck("Section", "(First|Last)");
  public static final RequestParameter REFRESH_RATE = RequestParameter.withLengthCheck("RefreshRate");
  
  /** Check user input can form a {@link SimpleCriteria}.  */
  @Override  protected void validateUserInput() throws AppException {
    try {
      ModelFromRequest builder = new ModelFromRequest(getRequestParser());
      fCriteria = builder.build(SimpleCriteria.class, LOG_FOR, SECTION, NUM_LINES, REFRESH_RATE);
      fLogger.fine(fCriteria.toString());
    }
    catch (ModelCtorException ex){
      addError(ex);
    }
  }
  
  /** List the log file text according to input criteria.  */
  @Override protected void listSearchResults() throws AppException {
    LogFileDAO dao = new LogFileDAO(getRequestParser().getRequest());
    
    File mostRecentLog = dao.getMostRecentLogFile(fCriteria.getLogFor());
    if( mostRecentLog != null ) {
      addToRequest("mostRecentLog", mostRecentLog);
      addToRequest("mostRecentLogDate", new Date(mostRecentLog.lastModified()));
      addToRequest("mostRecentLogSize", mostRecentLog.length());
      addToRequest(ITEMS_FOR_LISTING, dao.getLogFileContents(mostRecentLog, fCriteria));
      
      if ( fCriteria.getRefreshRate() != null ) {
        fLogger.fine("Auto-refreshing screen every " + fCriteria.getRefreshRate() + " seconds");
        refreshPage();  
      }
    }
    else {
      addError("No files detected in logging directory.");
    }
  }
  
  // PRIVATE //
  private SimpleCriteria fCriteria;
  private static final ResponsePage FORWARD = new ResponsePage("Raw Logs", "view.jsp", SimpleViewAction.class);
  private static final Logger fLogger = Util.getLogger(SimpleViewAction.class);
  
  private void refreshPage() {
    getRequestParser().getResponse().setHeader("Refresh", fCriteria.getRefreshRate() + "; " + getURI());
  }
  
  private String getURI(){
    String result = "SimpleViewAction.do?LogFor=" + fCriteria.getLogFor() + "&RefreshRate=" + fCriteria.getRefreshRate() + "&Operation=Search"; 
    if( fCriteria.getSection() != null ) {
      result = result + "&Section=" + fCriteria.getSection();
      result = result + "&NumLines=" + fCriteria.getNumLines();
    }
    fLogger.fine("Refresh URI: " + result);
    return "url=" + result;
  }
}
