package hirondelle.web4jtools.metrics.base;

import java.util.List;
import hirondelle.web4j.action.ActionImpl;
import hirondelle.web4j.model.AppException;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4j.action.ResponsePage;

/**
* Abstract Base Class for most Actions related to metrics. 
* 
* <P>Confirms that a scan of the base directory has been performed. 
* If not, then the user is advised to use the Summary page first.
*/
public abstract class MetricsAction extends ActionImpl {

  /** Full constructor. */
  public MetricsAction(ResponsePage aResponsePage, RequestParser aRequestParser) {
    super(aResponsePage, aRequestParser);
  }
  
  /**
  * <b>Template</b> method. 
  * 
  *  If the {@link #fFileList} is present in session scope as expected, then {@link #calculateMetric()} 
  *  is called; otherwise, an error message is presented to the user. 
  */
  @Override public ResponsePage execute() throws AppException {
    fFileList = (List<FileInfo>)getFromSession(BaseInfoAction.FILE_INFO_LIST_KEY);
    if ( fFileList == null ) {
      addError(ERROR_MESSAGE);
    }
    else {
      calculateMetric();
    }
    return getResponsePage();
  }
  
  /** Abstract method implemented by subclasses, and called by {@link #execute}. */
  protected abstract void calculateMetric();
  
  /**
  * If this {@code List<FileInfo>} is not in session scope, then an error message is 
  * presented to the user. This is is basic data structure used for source code statistics. 
  * It represents data that is read in when the user 'scans the source code', 
  * using the Summary page.
  */
  protected List<FileInfo> fFileList;
  
  private static final String ERROR_MESSAGE = "Please use Summary page to first scan source code.";
}
