package hirondelle.web4jtools.metrics.histogram;

import hirondelle.web4j.action.ResponsePage;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4jtools.metrics.base.FileInfo;
import hirondelle.web4jtools.metrics.base.MetricsAction;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
*  Display a breakdown of the number of lines for .java files, as a histogram.
*/
public final class HistogramAction extends MetricsAction {

  public HistogramAction(RequestParser aRequestParser) {
    super(FORWARD, aRequestParser);
  }
  
  /** Calculate histogram buckets, and show to user. */
  protected void calculateMetric() {
    createBuckets();
    calcBucketCounts(fFileList);
    addToRequest("buckets", fBuckets);
  }
  
  // PRIVATE //
  private static final ResponsePage FORWARD = new ResponsePage("Breakdown of .java File Sizes", "view.jsp", HistogramAction.class);
  private List<Bucket> fBuckets = new ArrayList<Bucket>();
  
  private void createBuckets(){
    fBuckets.add(new Bucket(0,25));
    fBuckets.add(new Bucket(26,50));
    fBuckets.add(new Bucket(51,75));
    fBuckets.add(new Bucket(76,100));
    fBuckets.add(new Bucket(101,125));
    fBuckets.add(new Bucket(126,150));
    fBuckets.add(new Bucket(151,175));
    fBuckets.add(new Bucket(176,200));
    fBuckets.add(new Bucket(201,225));
    fBuckets.add(new Bucket(226,250));
    fBuckets.add(new Bucket(251,275));
    fBuckets.add(new Bucket(276,300));
    fBuckets.add(new Bucket(301));
  }
  
  private void calcBucketCounts(List<FileInfo> aFiles){
    //need iterator since altering state of items in the list
    Iterator<FileInfo> iter = aFiles.iterator();
    while ( iter.hasNext() ) {
      FileInfo file = iter.next();
      if( file.isJavaSourceFile() ) {
        Integer numLines = file.getNumLines();
        addToCorrectBucket(numLines);
      }
    }
  }
  
  private void addToCorrectBucket(Integer aNumLines){
    Iterator<Bucket> iter = fBuckets.iterator();
    while ( iter.hasNext() ) {
      Bucket bucket = iter.next();
      if ( bucket.getMax() == null || aNumLines <= bucket.getMax() ) {
        bucket.incrementCount();
        break;
      }
    }
  }
}
