package hirondelle.web4jtools.metrics.lines;

import hirondelle.web4j.security.SafeText;
import hirondelle.web4jtools.metrics.base.FileInfo;
import hirondelle.web4j.util.Util;
import hirondelle.web4j.model.ModelUtil;

/**
* Model Object for line stats for a single file extension.
* <P>This class is mutable.  
*/
public final class LineStat {
  
  /** Full constructor. */
  public LineStat(SafeText aExtension) {
    fExtension = aExtension;
  }
  
  /** Return the file extension for this stat. */
  public SafeText getExtension(){
    return fExtension;
  }
  
  /** Return the number of lines for this extension.  */
  public Long getNumLines(){
    return fNumLines;  
  }
  
  /** Return the number of files for this extension.  */
  public Long getNumFiles(){
    return fNumFiles;
  }
  
  /** Return (num lines / num files). */
  public Long getAverageLinesPerFile(){
    return fNumLines / fNumFiles; //integer division will truncate remainder
  }
  
  /** Add a new file to this stat, if its extension matches this object.  */
  public void add(FileInfo aFileInfo){
    if ( ! aFileInfo.getExtension().equals(fExtension) ) {
      throw new AssertionError("FileInfo object has extension " + Util.quote(aFileInfo.getExtension()) + ", but expecting only extension " + Util.quote(getExtension()));
    }
    fNumFiles = fNumFiles + 1;
    fNumLines = fNumLines + aFileInfo.getNumLines();
  }
  
  public String toString(){
    return ModelUtil.toStringFor(this);
  }
  
  public boolean equals(Object aThat){
    Boolean result = ModelUtil.quickEquals(this, aThat);
    if( result == null){
      LineStat that = (LineStat)aThat;
      result = ModelUtil.equalsFor(this.getSignificantFields(), that.getSignificantFields());
    }
    return result;
  }
  
  public int hashCode(){
    //no cache - mutable
    return ModelUtil.hashCodeFor(getSignificantFields());
  }
  
  // PRIVATE //
  private SafeText fExtension;
  private long fNumLines;
  private long fNumFiles;
  
  private Object[] getSignificantFields(){
    return new Object[]{fExtension, fNumFiles, fNumLines};
  }
}
