package hirondelle.web4jtools.metrics.lines;

import java.util.*;
import hirondelle.web4jtools.metrics.base.FileInfo;
import hirondelle.web4j.security.SafeText;

/**
* Model Object for calculating total lines per file extension, for all extensions.
* This class uses a {@code List<LineStat>}, one for each file extension.
* <P>This class is mutable.
*/
final class LinesCounter {

  /** Add another file to this counter. */
  public void add(FileInfo aFileInfo) {
    SafeText extension = aFileInfo.getExtension();
    if ( ! isKnownExtension(extension) ){
      addNewExtension(aFileInfo);
    }
    addNumbers(aFileInfo);
  }

  /** Return the stats to be displayed to the user.  */
  public List<LineStat> getStats(){
    return fStatsList;
  }

  /** Return the total number of lines for all file extensions.  */
  public long getTotalLines() {
    long result = 0;
    for(LineStat lineStat : fStatsList){
      result = result + lineStat.getNumLines();
    }
    return result;
  }
  
  /** Return the total number of files for all extensions. */
  public long getTotalFiles(){
    long result = 0;
    for(LineStat lineStat : fStatsList) {
      result = result + lineStat.getNumFiles();
    }
    return result;
  }
  
  // PRIVATE  //
  private final List<LineStat> fStatsList = new ArrayList<LineStat>();
  
  private boolean isKnownExtension(SafeText aExt){
    boolean result = false;
    for(LineStat lineStat: fStatsList){
      if ( lineStat.getExtension().equals(aExt) ){
        result = true;
        break;
      }
    }
    return result;
  }
  
  private void addNewExtension(FileInfo aFileInfo){
    LineStat lineStat = new LineStat(aFileInfo.getExtension());
    fStatsList.add(lineStat);
  }
  
  private void addNumbers( FileInfo aFileInfo){
    for(LineStat lineStat: fStatsList){
      if ( lineStat.getExtension().equals(aFileInfo.getExtension()) ){
        lineStat.add(aFileInfo);
        break;
      }
    }
  }
}
