package hirondelle.web4jtools.metrics.tests;

import hirondelle.web4j.action.ResponsePage;
import hirondelle.web4j.request.RequestParser;
import hirondelle.web4jtools.metrics.base.FileInfo;
import hirondelle.web4jtools.metrics.base.MetricsAction;

import java.util.ArrayList;
import java.util.List;

/**
* List the unit test classes.
* 
* <P>Uses the <tt>UnitTestFingerprint</tt> setting in <tt>web.xml</tt> to 
* identify test classes.
*/
public final class TestsAction extends MetricsAction  {

  /** Full constructor. */
  public TestsAction(RequestParser aRequestParser){
    super(FORWARD, aRequestParser);
  }

  /** Show the test class metrics to the user. */
  protected void calculateMetric() {
    scanFiles(fFileList);
    addToRequest("testClasses", fTestFiles);
    addToRequest("numTestLines", fNumTestLines);
  }
  
  // PRIVATE //
  private static final ResponsePage FORWARD = new ResponsePage("Test Frequency", "view.jsp", TestsAction.class);
  private List<FileInfo> fTestFiles = new ArrayList<FileInfo>();
  private long fNumTestLines;
  
  private void scanFiles(List<FileInfo> aFiles){
    for (FileInfo fileInfo : aFiles){
      if ( fileInfo.isUnitTest() ) {
        fTestFiles.add(fileInfo);
        fNumTestLines = fNumTestLines + fileInfo.getNumLines();
      }
    }
  }
}
