package hirondelle.web4jtools.taglet;

import com.sun.tools.doclets.Taglet;    
import com.sun.javadoc.*;               
import java.util.Map;
import static hirondelle.web4j.util.Consts.NEW_LINE;
import hirondelle.web4j.util.Util;

/**
* Taglet for linking to <tt>.jsp</tt> files.
*
* <P>The <tt>.jsp</tt> files need to be copied into the javadoc tree. 
* The typical use case is to place the <tt>.jsp</tt> file in the same 
* directory as the class that references it. 
* 
* <P>Example use case :<br>
* <tt>&ampview view.jsp</tt>
*/
public final class ViewTaglet implements Taglet {
  
  /** Register this taglet with the javadoc tool, under the taglet name 'view'.  */
  public static void register(Map aTagletMap){
    if ( aTagletMap.get(TAGLET_NAME) != null ) {
      aTagletMap.remove(TAGLET_NAME);
    }
    aTagletMap.put(TAGLET_NAME, new ViewTaglet());
  }
  
  /** Return 'view'. */
  public String getName() {
    return TAGLET_NAME;
  }

  /** Return <tt>false</tt>. */
  public boolean isInlineTag() {
    return false;
  }
  
  /** Return <tt>false</tt>. */
  public boolean inOverview() {
    return false;
  }
  
  /** Return <tt>false</tt>. */
  public boolean inPackage() {
    return false;
  }
  
  /** Return <tt>true</tt>. */
  public boolean inType() {
    return true;
  }
  
  /** Return <tt>false</tt>. */
  public boolean inConstructor() {
    return false;
  }
  
  /** Return <tt>false</tt>. */
  public boolean inMethod() {
    return false;
  }
  
  /** Return <tt>false</tt>. */
  public boolean inField() {
    return false;
  }
  
  /** Render a series of <tt>&amp;view</tt> items.  */
  public String toString(Tag[] aTags) {
    StringBuilder result = new StringBuilder();
    if ( aTags.length != 0 ) {
      result.append(TAGLET_HEADER);
      result.append(NEW_LINE );
      result.append("<ul>" + NEW_LINE);
      for(Tag tag: aTags){
        if( Util.textHasContent(tag.text()) ) {
          result.append("<li>" + getLink(tag) + NEW_LINE);
        }
      }
      result.append("</ul>" + NEW_LINE);
    }
    return result.toString();
  }
  
  /** Render a single <tt>&amp;view</tt> item.  */
  public String toString(Tag aTag) {
    String result = "";
    if( Util.textHasContent(aTag.text()) )  {
      result = TAGLET_HEADER + getLink(aTag) + NEW_LINE;
    }
    return result;
  }
  
  // PRIVATE //
  private static final String TAGLET_NAME = "view";
  private static final String TAGLET_HEADER = "<b>View :</b> ";
  
  private String getLink(Tag aTag){
    return "<a href='" + aTag.text() +  ".txt'><tt>" + aTag.text() + "</tt></a>";
  }
}
