package hirondelle.web4jtools.util;

import hirondelle.web4j.model.Validator;
import hirondelle.web4j.security.SafeText;
import java.util.regex.*;

/**
* Custom validations. 
* 
* <P>This is an example of extending the framework's <tt>Check</tt> class with 
* custom validations. Note that the name of this class is the same as the name of 
* the framework class. This is unusual. It allows the calling code to retain the same 
* look when using custom validations.
*/
public final class Check extends hirondelle.web4j.model.Check {

  /**
  * Return <tt>true</tt> only if <tt>Object.toString()</tt> forms a valid regular expression. 
  * <P>If the <tt>Object</tt> is an instance of <tt>SafeText</tt>, then perform the test on 
  * <tt>SafeText.getRawString()</tt> instead. 
  */
  public static Validator isRegex(){
    class CheckRegex implements Validator {
      public boolean isValid(Object aObject) {
        boolean result = true;
        String pattern = null;
        
        if ( aObject instanceof SafeText ) {
          SafeText safeText = (SafeText)aObject;
          pattern = safeText.getRawString();
        }
        else {
          pattern = aObject.toString();
        }
        
        try {
          Pattern regex = Pattern.compile(pattern);
        }
        catch (PatternSyntaxException ex){
          result = false;
        }
        return result;
      }
    }
     return new CheckRegex();
  }
}
