package hirondelle.web4jtools.util;

import java.io.IOException;
import javax.servlet.jsp.JspException;
import java.util.Scanner;
import hirondelle.web4j.ui.tag.TagHelper;
import hirondelle.web4j.util.Util;

/**
* Remove all empty lines in the body of the tag. 
* 
* <P>In addition, in JSP 2.1, you may remove empty lines <em>associated with directives</em> 
* by using the following directive at the top of your JSP :
*  
* <P><tt>&lt;%@page trimDirectiveWhitespaces="true"%&gt;</tt>
*/
public final class NoEmptyLinesTag extends TagHelper {

  @Override protected String getEmittedText(String aBody) throws JspException, IOException {
    StringBuilder result = new StringBuilder();
    
    Scanner scanner = new Scanner(aBody);
    while ( scanner.hasNextLine() ) {
      addNonEmptyLineToResult(scanner.nextLine(), result);
    }
    scanner.close();
    
    return result.toString();
  }
  
  // PRIVATE //
  private void addNonEmptyLineToResult(String aLine, StringBuilder aResult){
    if( Util.textHasContent(aLine) ) {
      aResult.append(aLine);
    }
  }
}
